#!/usr/bin/env python
# -*- coding: utf-8 -*-

# # 2A.eco - Mise en pratique des séances 1 et 2 - Utilisation de pandas et visualisation - correction
# 
# Correction de l'exercice 2 et manipulations classiques de texte.

# In[1]:


get_ipython().run_line_magic('matplotlib', 'inline')


# In[2]:


from jyquickhelper import add_notebook_menu
add_notebook_menu()


# In[3]:


from pyensae.datasource import download_data
files = download_data("td2a_eco_exercices_de_manipulation_de_donnees.zip",
                      url="https://github.com/sdpython/ensae_teaching_cs/raw/master/_doc/notebooks/td2a_eco/data/")
files


# ## Exercice 2 - Les villes
# 
# Durée : 40 minutes
# 
# 1. Importer la base des villes villes.xls
# 2. Les noms de variables et les observations contiennent des espaces inutiles (exemple : 'MAJ   ') : commnecer par nettoyer l'ensemble des chaines de caractères (à la fois dans les noms de colonnes et dans les observations)
# 3. Trouver le nombre de codes INSEE différents (attention aux doublons)
# 4. Comment calculer rapidement la moyenne, le nombre et le maximum pour chaque variable numérique ? (une ligne de code)
# 5. Compter le nombre de villes dans chaque Region et en faire un dictionnaire où la clé est la région et la valeur le nombre de villes
# 6. Représenter les communes en utilisant  
# 
#     * matplotlib   
#     * une librairie de cartographie (ex : folium)  

# In[4]:


import pandas
df_villes = pandas.read_csv("villes.txt", sep="\t", encoding="utf-8")
print(df_villes.columns)


# In[5]:


df_villes.head()


# ## Nettoyage des noms

# In[6]:


# Corriger les espaces en trop
# solution pour les espaces
# les colonnes
df_villes.rename(columns=lambda x: x.strip(),inplace = True)
# les observations
df_villes['Nom Ville'] = df_villes[['Nom Ville']].applymap(lambda x: x.strip())
df_villes['MAJ'] = df_villes[['MAJ']].applymap(lambda x: x.strip())


# In[7]:


df_villes.columns


# ## Nombre de codes commune

# In[8]:


len(df_villes['Code INSEE'].unique())


# ## Stats desc

# In[9]:


df_villes.describe()


# ## Régions et nombre de communes

# In[10]:


df_villes.groupby(['Code Région']).size().to_dict()


# ## Représenter visuellement les communes
# 
# La conversion depuis Excel (un copier coller) a laissé quelques cellules négative et presque nulles ``   - ``. On les remplace par des valeurs nulles.

# In[11]:


import pandas
df_villes.Longitude = df_villes.Longitude.apply(lambda x: "0" if x.strip() == "-" else x)
df_villes.Longitude = pandas.to_numeric(df_villes.Longitude)


# ### matplotlib

# In[12]:


import matplotlib.pyplot as plt
plt.figure(figsize=(10,10))
plt.scatter(df_villes.Longitude, df_villes.Latitude, s=0.1)


# ### Exemple avec Folium

# In[13]:


import folium
import random

locations = df_villes[['Latitude', 'Longitude']].copy()
print(locations.shape, locations.dropna().shape)
locations.dropna(inplace = True)

locationlist = locations.values.tolist()
len(locationlist)
locationlist[7]


# In[14]:


communes_random = random.sample(locationlist, 50)


# In[15]:


map = folium.Map(location=[47.088615, 2.637424], zoom_start=6)
for point in range(0,len(communes_random)) :
    folium.Marker(communes_random[point]).add_to(map)
map


# In[16]: